#!/bin/bash

BIN_DIR=`dirname $0`
LIB_DIR=$BIN_DIR/../lib
LOGGING_PROPERTIES=$BIN_DIR/logging.properties

for jar in $LIB_DIR/*.jar; do
 if [ -z "$CP" ]; then
   CP=$jar
 else
   CP=$CP:$jar
 fi
done

JAVACMD=java
if [ -n "$JAVA_HOME" ]; then
  if [ -x "$JAVA_HOME/jre/bin/java" ]; then
    JAVACMD="$JAVA_HOME/jre/bin/java"
  else
    JAVACMD="$JAVA_HOME/bin/java"
  fi
fi

$JAVACMD -Xmx1024m -cp $CP \
    -Djava.util.logging.config.file=$LOGGING_PROPERTIES \
    fuku.xml2eb.Xml2Eb "$@"
